@@ -37,9 +37,13 @@
 """
 import copy
 from dataclasses import Field as DataclassesField
-from dataclasses import dataclass, asdict
+from dataclasses import asdict, dataclass
 from dataclasses import fields as dataclasses_fields
-from typing import Any, Callable, List, Literal, Optional, Union
+from typing import Any, Callable, List, Optional, Union
+try:
+    from typing import Literal
+except Exception:  # pragma: no cover
+    from typing_extensions import Literal
 
 
 @dataclass
@@ -206,6 +210,7 @@ class InstanceValidation(BasicValidation):
 
             exception = None
             errors = None
+            instance = None
 
             if isinstance(value, dict) or isinstance(value, annotation):
 
@@ -265,7 +270,7 @@ class InstanceValidation(BasicValidation):
 STR_ALIASES = {
     List: str(List),
     Union: str(Union),
-    Optional: str(Union),  # Представление как и у Union
+    Optional: str(Optional),
     Any: str(Any),
     Literal: str(Literal)
 }
@@ -353,7 +358,8 @@ class TypingValidation(InstanceValidation):
             Возавращает метод для проверки алиаса
         """
 
-        if annotation.startswith(STR_ALIASES[Union]):
+        if annotation.startswith(STR_ALIASES[Union]) or \
+            annotation.startswith(STR_ALIASES[Optional]):
             return self._is_union_instance
 
         elif annotation.startswith(STR_ALIASES[List]):
